| calcite_action_bar | R Documentation |
Action Bar is composed of calcite_action()s used for core operations in
the interface. When given an id, it acts as a Shiny input that reports
the text of the currently active action as input$id.
calcite_action_bar(
...,
id = NULL,
expand_disabled = NULL,
expanded = NULL,
floating = NULL,
layout = NULL,
overflow_actions_disabled = NULL,
position = NULL,
scale = NULL
)
... |
|
id |
Optional ID. When provided, |
expand_disabled |
When |
expanded |
When |
floating |
When |
layout |
Layout direction of the actions: |
overflow_actions_disabled |
When |
position |
Position of the component: |
scale |
Size of the expand action: |
When id is provided, input$id returns the text of the currently
active calcite_action(). The action bar manages active state automatically
— clicking an action activates it and deactivates all others.
observeEvent(input$my_bar, {
cat("Active action:", input$my_bar, "\n")
})
Use update_calcite() to programmatically set the active action by passing
the text value of the action to activate.
An object of class calcite_component
calcite_action_bar(
id = "my_bar",
calcite_action(text = "Layers", icon = "layers", active = TRUE),
calcite_action(text = "Legend", icon = "legend")
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.