- ...
Content for the button (default slot) - typically text or other elements
- id
Component ID (required for Shiny reactivity)
- alignment
Specifies the alignment of the component's elements: "center",
"end", "icon-end-space-between", "icon-start-space-between", "space-between",
or "start" (default: "center")
- appearance
Specifies the appearance style: "outline", "outline-fill",
"solid", or "transparent" (default: "solid")
- disabled
When TRUE, interaction is prevented and the component is
displayed with lower opacity (default: FALSE)
- download
Prompts the user to save the linked URL instead of navigating
to it. Can be TRUE or a string filename
- form
The id of the form that will be associated with the component
- href
Specifies the URL of the linked resource (absolute or relative path)
- icon_end
Specifies an icon to display at the end of the component
- icon_flip_rtl
Displays the iconStart and/or iconEnd as flipped when
the element direction is RTL: "both", "end", or "start"
- icon_start
Specifies an icon to display at the start of the component
- kind
Specifies the kind of the component: "brand", "danger", "inverse",
or "neutral" (default: "brand")
- label
Accessible name for the component
- loading
When TRUE, a busy indicator is displayed (default: FALSE)
- name
Specifies the name of the component on form submission
- rel
Defines the relationship between the href value and the current document
- round
When TRUE, adds a round style to the component (default: FALSE)
- scale
Specifies the size of the component: "s" (small), "m" (medium),
or "l" (large) (default: "m")
- split_child
Specifies if the component is a child of a calcite-split-button:
"primary", "secondary", or boolean
- target
Specifies where to open the linked document defined in href
- type
Specifies the default behavior: "button", "reset", or "submit"
(default: "button")
- width
Specifies the width of the component: "auto", "full", or "half"
(default: "auto"). Note: "half" is deprecated, use "full" instead.