- id
Component ID (required for Shiny reactivity)
- checked
When TRUE, the component is checked. Default: FALSE
- disabled
When TRUE, interaction is prevented and the component is
displayed with lower opacity. Default: FALSE
- form
Specifies the id of the component's associated form.
- indeterminate
When TRUE, the component is initially indeterminate,
independent from its checked value. Visual only. Default: FALSE
- label
Specifies an accessible label for the component.
- label_text
Specifies the component's label text.
- name
Specifies the name of the component. Required to pass the
component's value on form submission.
- required
When TRUE and the component resides in a form, the
component must have a value in order for the form to submit. Default: FALSE
- scale
Specifies the size of the component: "s", "m", or "l".
Default: "m"
- status
Specifies the status of the input field: "idle", "invalid",
or "valid". Default: "idle"
- value
The component's value.