| page_actionbar | R Documentation |
A convenience function that creates a common layout pattern: a shell with a navigation header, an action bar, and a side panel. This is ideal for map-based applications or tools with multiple layers/options.
page_actionbar(
...,
title = NULL,
header_actions = NULL,
actions = NULL,
panel_content = NULL,
panel_position = c("start", "end"),
panel_width = c("m", "s", "l"),
footer = NULL
)
... |
Main content area (typically a map or primary view) |
title |
Application title shown in the navigation header |
header_actions |
Optional actions for the header (e.g., user menu, settings).
These will be placed in the |
actions |
A |
panel_content |
A |
panel_position |
Position of the panel: |
panel_width |
Width of the shell panel: |
footer |
Optional footer content |
An object of class calcite_component containing a configured shell
page_actionbar(
title = "Wildlife Areas",
actions = calcite_action_bar(
calcite_action(text = "Add", icon = "plus"),
calcite_action(text = "Layers", icon = "layers", active = TRUE)
),
panel_content = calcite_panel(
heading = "Layers",
"Layer controls here"
),
"Map content here"
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.